Coverage report

# Coverage report: 33%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 903 | 604 | 0 | 33%
__init__.py | 0 | 0 | 0 | 100%
debye_calculator.py | 792 | 578 | 0 | 27%
test_debye_calculator.py | 74 | 0 | 0 | 100%
utility/__init__.py | 0 | 0 | 0 | 100%
utility/profiling.py | 37 | 26 | 0 | 30%

No items found using the specified filter.